@@ -12,16 +12,33 @@
 #
 ##############################################################################
 """Password manager interface
-
-$Id: interfaces.py 112030 2010-05-05 18:53:49Z tseaver $
 """
 import zope.interface
 
+
 class IPasswordManager(zope.interface.Interface):
-    """Password manager"""
+    """Password manager utility interface.
+    """
 
     def encodePassword(password):
-        """Return encoded data for the given password"""
+        """Return encoded data for the given password
+
+        Return encoded bytes.
+        """
 
     def checkPassword(encoded_password, password):
-        """Return whether the given encoded data coincide with the given password"""
+        """Does the encoded password match the given password?
+
+        Return True if they match, else False.
+        """
+
+
+class IMatchingPasswordManager(IPasswordManager):
+    """Password manager with hash matching support"""
+
+    def match(encoded_password):
+        """Was the given data was encoded with this manager's scheme?
+
+        Return True when the given data was encoded with the scheme
+        implemented by this password manager.
+        """
