@@ -11,22 +11,26 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Vocabulary of password manager utility names for use with zope.component and
-zope.schema.
+"""Vocabulary of password manager utility names
 
-$Id: vocabulary.py 97822 2009-03-11 07:59:29Z nadako $
+For use with zope.component and zope.schema.
 """
 from zope.component import getUtilitiesFor
 from zope.interface import directlyProvides
 from zope.schema.interfaces import IVocabularyFactory
-from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
+from zope.schema.vocabulary import SimpleTerm
+from zope.schema.vocabulary import SimpleVocabulary
 
 from zope.password.interfaces import IPasswordManager
 
+
 def PasswordManagerNamesVocabulary(context=None):
+    """Return a vocabulary listing password manager implementations by name.
+    """
     terms = []
     for name, util in getUtilitiesFor(IPasswordManager, context):
         terms.append(SimpleTerm(name))
     return SimpleVocabulary(terms)
 
+
 directlyProvides(PasswordManagerNamesVocabulary, IVocabularyFactory)
